==> haskell-wai-cors-0.2.6-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-46OQShZnsWGAGaCPAWPONz
key: wai-cors-0.2.6-46OQShZnsWGAGaCPAWPONz
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Cors
abi: 302c87a30941011f8d235fb99e109284
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-46OQShZnsWGAGaCPAWPONz
depends:
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15 base-4.10.1.0
    base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    transformers-0.5.2.0
abi-depends: attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=d64e813a02a40130dd55942d18e11638
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d=96f45cdb47a7c3edf990f6259e0df5e1
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.6-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-FC9MhDnIAvd5LUvnEfIjjU
key: wai-cors-0.2.6-FC9MhDnIAvd5LUvnEfIjjU
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
author: Lars Kuhtz <lakuhtz@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Cors
abi: aaa0246cfeecef56bcd1c447a7118f85
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-FC9MhDnIAvd5LUvnEfIjjU
depends:
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv base-4.10.1.0
    base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B
    wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    transformers-0.5.2.0
abi-depends: attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-unicode-symbols-0.2.2.4-5S5alRFlq9h8rWVSfYKtGd=d64e813a02a40130dd55942d18e11638
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             http-types-0.9.1-I5VXdG5r7Fv5gm7UD4yo3B=1fabab8f133df5a739212b62b9cfb522
             wai-3.2.1.2-IysNjphfNUmFMg0a4mHi4d=96f45cdb47a7c3edf990f6259e0df5e1
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
